pypiuma

-------
Install
-------

.. code-block::

   pip install pypiuma # TODO

-----
Usage
-----


---------
Run tests
---------

.. code-block::

   $ pip install -r requirements-dev.txt
   $ ./runtests.py --with-coverage
